
.. |Composition and Argument Binding| replace:: `Composition and Argument Binding`_

.. |composition| replace:: `composition`_
.. _`composition`: `Composition and Argument Binding`_

.. |argument binding| replace:: `argument binding`_
.. _`argument binding`: `Composition and Argument Binding`_


.. copyright:: Copyright ©  2001-2009 Aleksey Gurtovoy and David Abrahams
   Distributed under the Boost Software License, Version 1.0. (See accompanying
   file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
